package org.apache.commons.lang3.concurrent;

package .tmp;

import java.util.concurrent.ThreadFactory;
import org.apache.commons.lang3.Validate;
import org.apache.commons.lang3.builder.Builder;
import org.apache.commons.lang3.concurrent.BasicThreadFactory;

public class Builder implements Builder<BasicThreadFactory> {
  private ThreadFactory wrappedFactory;
  
  private Thread.UncaughtExceptionHandler exceptionHandler;
  
  private String namingPattern;
  
  private Integer priority;
  
  private Boolean daemon;
  
  public Builder wrappedFactory(ThreadFactory factory) {
    Validate.notNull(factory, "factory", new Object[0]);
    this.wrappedFactory = factory;
    return this;
  }
  
  public Builder namingPattern(String pattern) {
    Validate.notNull(pattern, "pattern", new Object[0]);
    this.namingPattern = pattern;
    return this;
  }
  
  public Builder daemon(boolean daemon) {
    this.daemon = Boolean.valueOf(daemon);
    return this;
  }
  
  public Builder priority(int priority) {
    this.priority = Integer.valueOf(priority);
    return this;
  }
  
  public Builder uncaughtExceptionHandler(Thread.UncaughtExceptionHandler handler) {
    Validate.notNull(handler, "handler", new Object[0]);
    this.exceptionHandler = handler;
    return this;
  }
  
  public void reset() {
    this.wrappedFactory = null;
    this.exceptionHandler = null;
    this.namingPattern = null;
    this.priority = null;
    this.daemon = null;
  }
  
  public BasicThreadFactory build() {
    BasicThreadFactory factory = new BasicThreadFactory(this, null);
    reset();
    return factory;
  }
}
